@@ -41,6 +41,7 @@ from .type_defs import (
     CreateCustomActionTypeOutputTypeDef,
     CreatePipelineOutputTypeDef,
     CurrentRevisionTypeDef,
+    EmptyResponseMetadataTypeDef,
     ExecutionDetailsTypeDef,
     FailureDetailsTypeDef,
     GetActionTypeOutputTypeDef,
@@ -177,11 +178,11 @@ class CodePipelineClient(BaseClient):
         category: ActionCategoryType,
         provider: str,
         version: str,
-        inputArtifactDetails: "ArtifactDetailsTypeDef",
-        outputArtifactDetails: "ArtifactDetailsTypeDef",
-        settings: "ActionTypeSettingsTypeDef" = ...,
-        configurationProperties: Sequence["ActionConfigurationPropertyTypeDef"] = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        inputArtifactDetails: ArtifactDetailsTypeDef,
+        outputArtifactDetails: ArtifactDetailsTypeDef,
+        settings: ActionTypeSettingsTypeDef = ...,
+        configurationProperties: Sequence[ActionConfigurationPropertyTypeDef] = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateCustomActionTypeOutputTypeDef:
         """
         Creates a new custom action that can be used in all pipelines associated with
@@ -192,7 +193,7 @@ class CodePipelineClient(BaseClient):
         """
 
     def create_pipeline(
-        self, *, pipeline: "PipelineDeclarationTypeDef", tags: Sequence["TagTypeDef"] = ...
+        self, *, pipeline: PipelineDeclarationTypeDef, tags: Sequence[TagTypeDef] = ...
     ) -> CreatePipelineOutputTypeDef:
         """
         Creates a pipeline.
@@ -203,7 +204,7 @@ class CodePipelineClient(BaseClient):
 
     def delete_custom_action_type(
         self, *, category: ActionCategoryType, provider: str, version: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Marks a custom action as deleted.
 
@@ -211,7 +212,7 @@ class CodePipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client/#delete_custom_action_type)
         """
 
-    def delete_pipeline(self, *, name: str) -> None:
+    def delete_pipeline(self, *, name: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified pipeline.
 
@@ -243,7 +244,7 @@ class CodePipelineClient(BaseClient):
         stageName: str,
         transitionType: StageTransitionTypeType,
         reason: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Prevents artifacts in a pipeline from transitioning to the next stage in the
         pipeline.
@@ -254,7 +255,7 @@ class CodePipelineClient(BaseClient):
 
     def enable_stage_transition(
         self, *, pipelineName: str, stageName: str, transitionType: StageTransitionTypeType
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Enables artifacts in a pipeline to transition to a stage in a pipeline.
 
@@ -338,7 +339,7 @@ class CodePipelineClient(BaseClient):
         self,
         *,
         pipelineName: str,
-        filter: "ActionExecutionFilterTypeDef" = ...,
+        filter: ActionExecutionFilterTypeDef = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListActionExecutionsOutputTypeDef:
@@ -407,7 +408,7 @@ class CodePipelineClient(BaseClient):
     def poll_for_jobs(
         self,
         *,
-        actionTypeId: "ActionTypeIdTypeDef",
+        actionTypeId: ActionTypeIdTypeDef,
         maxBatchSize: int = ...,
         queryParam: Mapping[str, str] = ...
     ) -> PollForJobsOutputTypeDef:
@@ -419,7 +420,7 @@ class CodePipelineClient(BaseClient):
         """
 
     def poll_for_third_party_jobs(
-        self, *, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = ...
+        self, *, actionTypeId: ActionTypeIdTypeDef, maxBatchSize: int = ...
     ) -> PollForThirdPartyJobsOutputTypeDef:
         """
         Determines whether there are any third party jobs for a job worker to act on.
@@ -434,7 +435,7 @@ class CodePipelineClient(BaseClient):
         pipelineName: str,
         stageName: str,
         actionName: str,
-        actionRevision: "ActionRevisionTypeDef"
+        actionRevision: ActionRevisionTypeDef
     ) -> PutActionRevisionOutputTypeDef:
         """
         Provides information to AWS CodePipeline about new revisions to a source.
@@ -449,7 +450,7 @@ class CodePipelineClient(BaseClient):
         pipelineName: str,
         stageName: str,
         actionName: str,
-        result: "ApprovalResultTypeDef",
+        result: ApprovalResultTypeDef,
         token: str
     ) -> PutApprovalResultOutputTypeDef:
         """
@@ -460,8 +461,8 @@ class CodePipelineClient(BaseClient):
         """
 
     def put_job_failure_result(
-        self, *, jobId: str, failureDetails: "FailureDetailsTypeDef"
-    ) -> None:
+        self, *, jobId: str, failureDetails: FailureDetailsTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Represents the failure of a job as returned to the pipeline by a job worker.
 
@@ -473,11 +474,11 @@ class CodePipelineClient(BaseClient):
         self,
         *,
         jobId: str,
-        currentRevision: "CurrentRevisionTypeDef" = ...,
+        currentRevision: CurrentRevisionTypeDef = ...,
         continuationToken: str = ...,
-        executionDetails: "ExecutionDetailsTypeDef" = ...,
+        executionDetails: ExecutionDetailsTypeDef = ...,
         outputVariables: Mapping[str, str] = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Represents the success of a job as returned to the pipeline by a job worker.
 
@@ -486,8 +487,8 @@ class CodePipelineClient(BaseClient):
         """
 
     def put_third_party_job_failure_result(
-        self, *, jobId: str, clientToken: str, failureDetails: "FailureDetailsTypeDef"
-    ) -> None:
+        self, *, jobId: str, clientToken: str, failureDetails: FailureDetailsTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Represents the failure of a third party job as returned to the pipeline by a job
         worker.
@@ -501,10 +502,10 @@ class CodePipelineClient(BaseClient):
         *,
         jobId: str,
         clientToken: str,
-        currentRevision: "CurrentRevisionTypeDef" = ...,
+        currentRevision: CurrentRevisionTypeDef = ...,
         continuationToken: str = ...,
-        executionDetails: "ExecutionDetailsTypeDef" = ...
-    ) -> None:
+        executionDetails: ExecutionDetailsTypeDef = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Represents the success of a third party job as returned to the pipeline by a job
         worker.
@@ -514,7 +515,7 @@ class CodePipelineClient(BaseClient):
         """
 
     def put_webhook(
-        self, *, webhook: "WebhookDefinitionTypeDef", tags: Sequence["TagTypeDef"] = ...
+        self, *, webhook: WebhookDefinitionTypeDef, tags: Sequence[TagTypeDef] = ...
     ) -> PutWebhookOutputTypeDef:
         """
         Defines a webhook and returns a unique webhook URL generated by CodePipeline.
@@ -567,7 +568,7 @@ class CodePipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client/#stop_pipeline_execution)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds to or modifies the tags of the given resource.
 
@@ -583,7 +584,9 @@ class CodePipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client/#untag_resource)
         """
 
-    def update_action_type(self, *, actionType: "ActionTypeDeclarationTypeDef") -> None:
+    def update_action_type(
+        self, *, actionType: ActionTypeDeclarationTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates an action type that was created with any supported integration model,
         where the action type is to be used by customers of the action type provider.
@@ -593,7 +596,7 @@ class CodePipelineClient(BaseClient):
         """
 
     def update_pipeline(
-        self, *, pipeline: "PipelineDeclarationTypeDef"
+        self, *, pipeline: PipelineDeclarationTypeDef
     ) -> UpdatePipelineOutputTypeDef:
         """
         Updates a specified pipeline with edits or changes to its structure.
